@@ -5,13 +5,13 @@ from rest_framework.templatetags.rest_framework import replace_query_param
 from rest_framework_ember.utils import get_resource_name
 
 
-class NextPageLinkField(serializers.Field):
+class NextPageLinkField(serializers.ReadOnlyField):
     """
     Field that returns a link to the next page in paginated results.
     """
     page_field = 'page'
 
-    def to_native(self, value):
+    def to_representation(self, value):
         if not value.has_next():
             return None
         page = value.next_page_number()
@@ -20,25 +20,25 @@ class NextPageLinkField(serializers.Field):
         return replace_query_param(url, self.page_field, page)
 
 
-class NextPageField(serializers.Field):
+class NextPageField(serializers.ReadOnlyField):
     """
     Field that returns a link to the next page in paginated results.
     """
     page_field = 'page'
 
-    def to_native(self, value):
+    def to_representation(self, value):
         if not value.has_next():
             return None
         return value.next_page_number()
 
 
-class PreviousPageLinkField(serializers.Field):
+class PreviousPageLinkField(serializers.ReadOnlyField):
     """
     Field that returns a link to the previous page in paginated results.
     """
     page_field = 'page'
 
-    def to_native(self, value):
+    def to_representation(self, value):
         if not value.has_previous():
             return None
         page = value.previous_page_number()
@@ -47,34 +47,42 @@ class PreviousPageLinkField(serializers.Field):
         return replace_query_param(url, self.page_field, page)
 
 
-class PreviousPageField(serializers.Field):
+class PreviousPageField(serializers.ReadOnlyField):
     """
     Field that returns a link to the previous page in paginated results.
     """
     page_field = 'page'
 
-    def to_native(self, value):
+    def to_representation(self, value):
         if not value.has_previous():
             return None
         return value.previous_page_number()
 
 
-class PageField(serializers.Field):
+class PageField(serializers.ReadOnlyField):
     """
     Field that returns a link to the previous page in paginated results.
     """
     page_field = 'page'
 
-    def to_native(self, value):
+    def to_representation(self, value):
         return value.number
 
 
 
-class EmberPaginationSerializer(pagination.BasePaginationSerializer):
+class PaginationSerializer(pagination.BasePaginationSerializer):
     next = NextPageField(source='*')
     next_link = NextPageLinkField(source='*')
     page = PageField(source='*')
     previous = PreviousPageField(source='*')
     previous_link = PreviousPageLinkField(source='*')
-    count = serializers.Field(source='paginator.count')
+    count = serializers.ReadOnlyField(source='paginator.count')
+    total = serializers.ReadOnlyField(source='paginator.num_pages')
+
+
+class EmberPaginationSerializer(PaginationSerializer):
+    """
+    Backwards compatibility for name change
+    """
+    pass
 
