@@ -1,8 +1,12 @@
-import copy
-from rest_framework import renderers
+import inflection
 
+from django.conf import settings
+
+from rest_framework import renderers
 from rest_framework_ember.utils import get_resource_name
 
+from .utils import format_keys, format_resource_name
+
 
 class JSONRenderer(renderers.JSONRenderer):
     """
@@ -18,19 +22,26 @@ class JSONRenderer(renderers.JSONRenderer):
     """
     def render(self, data, accepted_media_type=None, renderer_context=None):
         view = renderer_context.get('view')
-
         resource_name = get_resource_name(view)
 
         if resource_name == False:
             return super(JSONRenderer, self).render(
                 data, accepted_media_type, renderer_context)
 
+        data = format_keys(data, 'camelize')
+
         try:
-            data_copy = copy.copy(data)
-            content = data_copy.pop('results')
-            data = {resource_name : content, "meta" : data_copy}
+            content = data.pop('results')
+            resource_name = format_resource_name(content, resource_name)
+            data = {resource_name : content, "meta" : data}
         except (TypeError, KeyError, AttributeError) as e:
+
+            # Default behavior
+            if not resource_name == 'data':
+                format_keys(data, 'camelize')
+                resource_name = format_resource_name(data, resource_name)
+
             data = {resource_name : data}
+
         return super(JSONRenderer, self).render(
             data, accepted_media_type, renderer_context)
-
